Plugins/CheckerPlugins/CodeStyleChecker/NamingStyleChecker.py

changeset 5147
d39dd5cee0c8
parent 4631
5c1a96925da4
child 5389
9b1c800daff3
--- a/Plugins/CheckerPlugins/CodeStyleChecker/NamingStyleChecker.py	Sun Sep 04 16:50:23 2016 +0200
+++ b/Plugins/CheckerPlugins/CodeStyleChecker/NamingStyleChecker.py	Sun Sep 04 17:16:38 2016 +0200
@@ -35,11 +35,11 @@
     
     def __init__(self, tree, filename, options):
         """
-        Constructor (according to 'extended' pep8.py API)
+        Constructor (according to 'extended' pycodestyle.py API)
         
         @param tree AST tree of the source file
         @param filename name of the source file (string)
-        @param options options as parsed by pep8.StyleGuide
+        @param options options as parsed by pycodestyle.StyleGuide
         """
         self.__parents = collections.deque()
         self.__tree = tree
@@ -79,7 +79,7 @@
 
     def run(self):
         """
         Public method run by the pep8.py checker.
         
         @return tuple giving line number, offset within line, code and
             checker function
@@ -79,7 +79,7 @@
     def run(self):
         """
-        Public method run by the pep8.py checker.
+        Public method run by the pycodestyle.py checker.
         
         @return tuple giving line number, offset within line, code and

eric ide

mercurial